/*
MIT License

Copyright (c) 2018 Brian T. Park

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

#ifndef ACE_SEGMENT_STYLER_H
#define ACE_SEGMENT_STYLER_H

namespace ace_segment {

/**
 * Interface for classes which apply a style to the given bit pattern and
 * brightness.
 */
class Styler {
  public:
    /** Constructor. */
    Styler() {}

    /** Destructor. */
    virtual ~Styler() {}

    /** Called once per frame to update the internal variables of the object. */
    virtual void calcForFrame() = 0;

    /** Changes updates the brightness for current frame. */
    virtual void apply(uint8_t* pattern, uint8_t* brightness) = 0;

    /** Requires driver support for brightness control if true. */
    virtual bool requiresBrightness() = 0;

  private:
    // disable copy-constructor and assignment operator
    Styler(const Styler&) = delete;
    Styler& operator=(const Styler&) = delete;
};

}

#endif
